@@ -46,8 +46,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.11.12_p2' "
-                "'--htmldir=/usr/share/doc/python-3.11.12_p2/html' "
+                "'--docdir=/usr/share/doc/python-3.11.12' "
+                "'--htmldir=/usr/share/doc/python-3.11.12/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -67,9 +67,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.12_p2/work/Python-3.11.12/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.12/work/Python-3.11.12/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.12_p2/work/Python-3.11.12/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.12/work/Python-3.11.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -614,14 +614,15 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
- 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
-                 '-m 644',
- 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.3oo8g5el/bin/ebuild-helpers/xattr/install '
+            '-c',
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.3oo8g5el/bin/ebuild-helpers/xattr/install '
+                 '-c -m 644',
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.3oo8g5el/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.3oo8g5el/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.3oo8g5el/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -993,7 +994,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'x86_64-pc-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.12_p2/work/Python-3.11.12',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.12/work/Python-3.11.12',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1037,10 +1038,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.12_p2/work/Python-3.11.12 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.12/work/Python-3.11.12 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.12_p2/work/Python-3.11.12 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.12/work/Python-3.11.12 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1071,8 +1072,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.12_p2/work/Python-3.11.12',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.12_p2/work/Python-3.11.12',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.12/work/Python-3.11.12',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.12/work/Python-3.11.12',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
